==> UPS-courier_v1.3.5.zip: UPS-courier v1.3.5/UPS-courier v1.3.5.oxp/scripts/UPSBoaKilled.js <==
/*this.name      = "ups_boa_killed"; 
this.author    = "eric walch"; 
this.copyright = " 2008 the Oolite team."; 
this.version   = "1.00"; */

this.shipDied = function(whom, why) {this.boaDied(whom, why);}
this.beingAttacked = function(whom) {this.boaAttacked(whom);}
this.shipSpawned = function() {this.boaAdded();}


this.boaAdded = function()
{
    ship.switchAI("route1UpsTraderJSAI.plist")
    this.oldStatus = this.ship.bounty
    delete this.didSpawn;
    delete this.boaAdded;
}

this.boaDied = function(whom, why) 
{ 
   LogWithClass("ups.boa.died", "Killed by " + whom + " by means of " + why); 
   if (whom == player) 
   { 
      missionVariables.ups_closecontact = "YES" // Killer was the player 
   } 
//   else 
//   { 
//      missionVariables.ups_closecontact = "NO" // Killer was an NPC 
//   } 
    player.commsMessage("I'll be back with help for revenge!!", 5);
    system.legacy_spawn("ups-container", 5);
    system.legacy_spawn("textilepod", 15);
    missionVariables.ups_container_count = "0";
    missionVariables.ups_container = "FOUND";
    if (player.isCloaked) 
    { 
        player.consoleMessage("Cloaking is cheating.", 6)
    }
    delete this.shipDied;
} 


this.beingAttacked = function(whom)
{ 
    if(whom == player) 
    {
      missionVariables.ups_closecontact = "YES" // Shooter was the player 
    if (player.isCloaked) 
    { 
        missionVariables.ups_closecontact = "NO" // don't honour a cloaked shot 
    }
    }
    else
    {
      missionVariables.ups_closecontact = "NO" // Shooter was NPC ship 
    }
}

this. checkPlayer = function()
{
 if(Math.round(player.position.distanceTo(this.ship)) > 30000) this.setClean()
 else this.setFugitive()
}


this.setClean = function()
{
    if(this.oldStatus = 0)
    {
        this.oldStatus = this.ship.bounty
        this.ship.bounty = 0
    }
}

this.setFugitive = function()
{
    if(this.oldStatus > 0)
    {
        this.ship.bounty = this.oldStatus
        this.oldStatus = 0
    }
}

==> UPS-courier_v1.3.6.zip: UPS-courier v1.3.6/UPS-courier v1.3.6.oxp/scripts/UPSBoaKilled.js <==
/*this.name      = "ups_boa_killed"; 
this.author    = "eric walch"; 
this.copyright = " 2008 the Oolite team."; 
this.version   = "1.00"; */

this.shipDied = function(whom, why) {this.boaDied(whom, why);}
this.beingAttacked = function(whom) {this.boaAttacked(whom);}
this.shipSpawned = function() {this.boaAdded();}


this.boaAdded = function()
{
    ship.switchAI("route1UpsTraderJSAI.plist")
    this.oldStatus = this.ship.bounty
    delete this.shipSpawned;
    delete this.boaAdded;
}

this.boaDied = function(whom, why) 
{ 
   LogWithClass("ups.boa.died", "Killed by " + whom + " by means of " + why); 
   if (whom == player) 
   { 
      missionVariables.ups_closecontact = "YES" // Killer was the player 
   } 
//   else 
//   { 
//      missionVariables.ups_closecontact = "NO" // Killer was an NPC 
//   } 
    player.commsMessage("I'll be back with help for revenge!!", 5);
    system.legacy_spawn("ups-container", 5);
    system.legacy_spawn("textilepod", 15);
    missionVariables.ups_container_count = "0";
    missionVariables.ups_container = "FOUND";
    if (player.isCloaked) 
    { 
        player.consoleMessage("Cloaking is cheating.", 6)
    }
    delete this.shipDied;
} 


this.beingAttacked = function(whom)
{ 
    if(whom == player) 
    {
      missionVariables.ups_closecontact = "YES" // Shooter was the player 
    if (player.isCloaked) 
    { 
        missionVariables.ups_closecontact = "NO" // don't honour a cloaked shot 
    }
    }
    else
    {
      missionVariables.ups_closecontact = "NO" // Shooter was NPC ship 
    }
}

this. checkPlayer = function()
{
 if(Math.round(player.position.distanceTo(this.ship)) > 30000) this.setClean()
 else this.setFugitive()
}


this.setClean = function()
{
    if(this.oldStatus == 0)
    {
        this.oldStatus = this.ship.bounty
        this.ship.bounty = 0
    }
}

this.setFugitive = function()
{
    if(this.oldStatus > 0)
    {
        this.ship.bounty = this.oldStatus
        this.oldStatus = 0
    }
}
